@@ -8,6 +8,8 @@ use std::collections::HashMap;
 use std::io;
 use std::io::BufRead;
 use std::io::BufReader;
+use std::path::Path;
+use std::path::PathBuf;
 use std::process;
 use std::process::ExitStatus;
 use std::sync::mpsc;
@@ -19,7 +21,7 @@ pub use color::Color;
 pub use standard_out_api::parse_command_string;
 pub use standard_out_api::run_commands_stdout;
 pub use standard_out_api::run_commands_stdout_with_options;
-pub use standard_out_api::StandardOutCommand;
+pub use standard_out_api::ConsoleCommand;
 
 pub use writer_api::run_commands_writer;
 pub use writer_api::run_commands_writer_with_options;
@@ -34,7 +36,7 @@ pub struct Command {
     name: String,
     command: String,
     args: Vec<String>,
-    cur_dir: Option<String>,
+    cur_dir: Option<PathBuf>,
     env: HashMap<String, String>,
 }
 
@@ -66,7 +68,7 @@ impl Command {
         })
     }
 
-    pub fn new_command_string<S, C>(name: S, command_string: C) -> Result<Command, CommandError>
+    pub fn full_cmd<S, C>(name: S, command_string: C) -> Result<Command, CommandError>
     where
         S: AsRef<str>,
         C: AsRef<str>,
@@ -83,9 +85,9 @@ impl Command {
 
     pub fn cur_dir<D>(mut self, dir: D) -> Self
     where
-        D: AsRef<str>,
+        D: AsRef<Path>,
     {
-        self.cur_dir = Some(dir.as_ref().to_string());
+        self.cur_dir = Some(dir.as_ref().to_path_buf());
         self
     }
 
